# BOUT++ examples

## Getting started

Some simple examples to get started are

* **conduction** This is discussed in the user manual, and solves a 1D diffusion equation
* **blob2d** A 2D simulation of a plasma blob. This is a more realistic simulation, simple enough
  to start with, but can be used as a starting point for novel studies
* **hasegawa-wakatani** Solves the H-W equations (optionally with modified zonal response) in 2D
* **test-staggered** shows how to use staggered grids in BOUT++

## Test suite

The test suite has moved to the [tests directory][../tests/README.md].
